*******************
Connected Component
*******************


.. doxygenclass:: Dune::MMeshConnectedComponent
  :members: children, size


.. doxygenclass:: Dune::MMeshInterfaceConnectedComponent
  :members: children, size
